// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:nim_core/nim_core.dart';

extension SystemNotifyInfo on SystemMessage {
  Future<NIMUser?> getFromUser() async {
    if (fromAccount == null) {
      return null;
    } else {
      var userResult =
          await NimCore.instance.userService.getUserInfo(fromAccount!);
      return userResult.data;
    }
  }

  Future<NIMTeam?> getTargetTeam() async {
    if (isTeamType() && targetId != null) {
      return NimCore.instance.teamService
          .queryTeam(targetId!)
          .then((value) => value.data);
    }
    return null;
  }

  Future<NotifyExtension> getNotifyExt() async {
    var user = await getFromUser();
    var team = await getTargetTeam();
    return NotifyExtension(fromUser: user, targetTeam: team);
  }

  bool isTeamType() {
    return type == SystemMessageType.applyJoinTeam ||
        type == SystemMessageType.rejectTeamApply ||
        type == SystemMessageType.teamInvite ||
        type == SystemMessageType.declineTeamInvite;
  }
}

class NotifyExtension {
  NIMTeam? targetTeam;
  NIMUser? fromUser;

  NotifyExtension({this.fromUser, this.targetTeam});
}
